// TIBCO Enterprise for JMS
// File: SimpleCons.java
// TIBCO Education Services
// Copyright 2003 - TIBCO Software Inc.
// ALL RIGHTS RESERVED

// ***** Step 1: Import the Jars
import javax.naming.*;
import javax.jms.*;
import java.util.Hashtable;

public class SimpleCons
{
	// ***** Step 2: Provide the correct values
	static final String  providerContextFactory =
			                            "com.sun.jndi.ldap.LdapCtxFactory";
	static final String  providerURL ="ldap://localhost:389/o=NetscapeRoot";

	public static void main(String[] args)
	{
		String 				topicName = null;
		Context 				jndiContext = null;
		ConnectionFactory			cFactory = null;
		Connection				conn = null;
		Session				session = null;
		Destination 			myDest=null;
		TextMessage				msg = null;
		MessageConsumer			myCons = null;

		if (args.length !=1)
		{
			System.out.println("Usage: java SimpleCons " + "<topic-name>");
			System.exit(1);
		}

		topicName = new String(args[0]);
		System.out.println("Listening on Topic : "+ topicName);


		// ***** Step 3: Get initial Context, create connection factory
		try
		{
			Hashtable env = new Hashtable();
			env.put(Context.INITIAL_CONTEXT_FACTORY,providerContextFactory);
			env.put(Context.PROVIDER_URL,providerURL);
			env.put(Context.SECURITY_PRINCIPAL, "uid=user01,ou=tibco.com,o=NetscapeRoot");
			env.put(Context.SECURITY_CREDENTIALS, "user01");
			jndiContext = new InitialContext(env);
			jndiContext.addToEnvironment(Context.OBJECT_FACTORIES, "com.tibco.tibjms.naming.TibjmsObjectFactory");
			jndiContext.addToEnvironment(Context.URL_PKG_PREFIXES, "com.tibco.tibjms.naming");
			cFactory = (ConnectionFactory)jndiContext.lookup("cn=CF01");

			// ***** Step 4: Lookup the Topic
			myDest = (Destination)jndiContext.lookup("cn=" + topicName);
			jndiContext.close();
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}

		try
		{
			// ***** Step 5: Create the connection and the session
			conn = cFactory.createConnection();
			session = conn.createSession(false,Session.AUTO_ACKNOWLEDGE);

			// ***** Step 6: Create the subscriber
			myCons = session.createConsumer(myDest);

			// ***** Step 7: Start the connection
			conn.start();

			while (true)
			{
				// ***** Step 8: Receive the message
				Message inMsg = myCons.receive(1);
				if  (inMsg != null)
				{
					// ***** Step 9: Check if it is a Text Message, and cast it
					if (inMsg instanceof TextMessage)
					{
						msg = (TextMessage)inMsg;
						System.out.println("Received: " + msg.getText());
					}
					else
					{
						System.out.println("Exiting Program" + inMsg);
						break;
					}
				}
			}
		}
		catch (JMSException e)
		{
			System.out.println("Exception in receive message  :" + e.toString());
			System.exit(1);
		}
		finally
		{
			if (conn != null)
			try
			{
				conn.close();
			}
			catch(JMSException e)
			{
				System.out.println("Exception:" + e.toString());
			}
		}
	}
}

