////////////////////////////////////////////////////
// TIBCO Enterprise for JMS - JAVA API
// File: SimpleProd.java
// TIBCO Education Services
// Copyright 2003 - TIBCO Software Inc.
// ALL RIGHTS RESERVED
////////////////////////////////////////////////////

// Step 1. Import the necessary Jars
import javax.jms.*;
import javax.naming.*;
import java.util.Hashtable;

public class SimpleProd
{
    // Step 2: Fill in the provider context factory and the provider URL
    static final String  providerContextFactory =
			                            "com.sun.jndi.ldap.LdapCtxFactory";
	static final String  providerURL ="ldap://localhost:389/o=NetscapeRoot";

	public static void main(String[] args)
	{
		String 				topicName = null;
		Context 				jndiContext = null;
		ConnectionFactory			cFactory = null;
		Connection				conn = null;
		Session				session = null;
		Destination 			myDest=null;
		MessageProducer			myProd = null;
		TextMessage				msg = null;

		if (args.length!=2)
		{
			System.out.println("Usage: java SimpleProd <Topic> <message>");
			System.exit(1);
		}

		topicName = new String(args[0]);
		System.out.println("Topic is:"+ topicName);


		// **** Step 3 Get initial Context
		try
		{
			Hashtable env = new Hashtable();
			env.put(Context.INITIAL_CONTEXT_FACTORY,providerContextFactory);
			env.put(Context.PROVIDER_URL,providerURL);
			env.put(Context.SECURITY_PRINCIPAL, "uid=user01,ou=tibco.com,o=NetscapeRoot");
			env.put(Context.SECURITY_CREDENTIALS, "user01");
			jndiContext = new InitialContext(env);
			jndiContext.addToEnvironment(Context.OBJECT_FACTORIES, "com.tibco.tibjms.naming.TibjmsObjectFactory");
			jndiContext.addToEnvironment(Context.URL_PKG_PREFIXES, "com.tibco.tibjms.naming");

			// **** Step 4 create connection factory
    			cFactory = (ConnectionFactory)jndiContext.lookup("cn=CF01");
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}


		try
		{
			// **** Step 5 Create Connection, Session
			conn = cFactory.createConnection();
			session = conn.createSession(false,Session.AUTO_ACKNOWLEDGE);

			// **** Step 6 lookup topic
			myDest = (Destination)jndiContext.lookup("cn=" + topicName);
			jndiContext.close();

			// **** Step 7 Create Producer
			myProd = session.createProducer(myDest);

			// **** Step 8 Create Text Message
			msg = session.createTextMessage();

			msg.setText(args[1]);
			System.out.println("Sending " + msg.getText());

			// **** Step 9 Send message
			myProd.send(msg);
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}
		catch (JMSException e)
		{
			System.out.println("Exception in send message :" + e.toString());
			System.exit(1);
		}
		finally
		{
			if (conn != null)
			try
			{
				// **** Step 10 Close the connection
				conn.close();
			}
			catch(JMSException e)
			{
				System.out.println("Exception:" + e.toString());
			}
		}
	}
}

