////////////////////////////////////////////////////
// TIBCO Enterprise for JMS - JAVA API
// TIBCO Education Services
// Copyright 2003 - TIBCO Software Inc.
// ALL RIGHTS RESERVED
////////////////////////////////////////////////////

import javax.jms.*;
import javax.naming.*;
import java.util.*;

public class Client2
{
	final static int REQCOUNT= 2;  // 2 requests at a time

	public static void main(String[] args)
	{
		String 			reqDestName = null, replyDestName= null;
		Context 			jndiContext = null;
		ConnectionFactory		cFactory = null;
		Connection			tconn = null;
		Session			tsession = null;
		Destination 			reqDest=null, replyDest= null;
		NRequestor			myRequestor = null;
		TextMessage			msg = null;

		if (args.length<2)
		{
			System.out.println("Usage: java Client2 <request-destination> <reply-destination>");
			System.exit(1);
		}

		reqDestName = args[0];
		replyDestName = args[1];

		System.out.println("Request to: " + reqDestName + " - Reply from: " + replyDestName);

		try
		{
	    		jndiContext = new InitialContext();
    			cFactory = (ConnectionFactory)jndiContext.lookup("ConnectionFactory");
			reqDest = (Destination)jndiContext.lookup(reqDestName);
			replyDest = (Destination)jndiContext.lookup(replyDestName);
		}
		catch (NamingException e)
		{
			System.out.println(e);
			System.exit(1);
		}

		try
		{
			tconn = (Connection)cFactory.createConnection();
			tsession = tconn.createSession(false,Session.AUTO_ACKNOWLEDGE);

                   //***** Step 1: Create an NRequestor for REQCOUNT requests

                   myRequestor= new NRequestor(REQCOUNT);

			msg = tsession.createTextMessage("QUERY");
                   tconn.start();

                   for  (int i= 0;  i<REQCOUNT;  ++i)
                   {
                      //***** Step 2: Send a request

                      myRequestor.request(reqDest, msg, replyDest, tsession);
                   }

                   Hashtable replies= null;
                   while  (replies==null)
                   {
                      //***** Step 3: Wait 3 seconds for all replies

                      replies= myRequestor.block(3000);

                      if  (replies==null)
                         System.out.println("Not done yet...");

                      else for (Enumeration e= replies.elements();  e.hasMoreElements();)
                      {
                         Object reply= e.nextElement();
                         if  (reply instanceof TextMessage) {
                            TextMessage m= (TextMessage)reply;
                            System.out.println("REPLY: " + m.getText());
                         }
                         else
                            System.out.println("REPLY: " + reply);
                      }
			}
		}
		catch (JMSException e)
		{
			System.out.println("Exception in send message :" + e.toString());
			System.exit(1);
		}
		finally
		{
			if (tconn != null)
			try
			{
				tconn.close();
			}
			catch(JMSException e)
			{
				System.out.println("Exception:" + e.toString());
			}
		}
	}
}
