/* Copyright 2005 TIBCO Software Inc. */

import javax.jms.*;
import java.util.*;
import javax.naming.*;

public class NRequestor implements MessageListener
{
   private int reqCount, replyCount;
   private Hashtable replyTable, consumerTable;

/**
 * Creates a multi-client object which simultaneously
 * issues n blocking request/reply calls
 */
   public NRequestor(int n)
   {
      reqCount= n;
      replyTable= new Hashtable(n);
      consumerTable= new Hashtable(n);
   }

   // Wait for more replies; give up after ms milliseconds
   private synchronized void P(int ms)
   {
      try { wait(ms); }
      catch(InterruptedException ix) {}
   }

   // If all replies have arrived then unblock
   private synchronized void V() { if  (--reqCount <= 0)  notify(); }

/**
 * Blocks until all replies arrive, but for no more than ms milliseconds
 */
   public Hashtable block(int ms)
   {
      P(ms);
      return  (reqCount > 0) ? null : replyTable;     
   }


/**
 * Issues a request. <B>NOTE:</B> pending requests must be abandoned using method quit,
 * otherwise open MessageListener's will prevent normal program exit.
 */
   public String request(Destination reqD, Message m, Destination replyD, Session s)
   {
      // Assume server puts request's CorrelationID into reply's CorrelationID
 
      String id= new java.rmi.server.UID().toString(); // Unique id
      try
      {
         //***** Step 1: Create a consumer for the id before sending request

         MessageConsumer c= s.createConsumer(replyD, "JMSCorrelationID='" + id + "'");
         consumerTable.put(id, c);

         //***** Step 2: Set this onMessage as the listener

         c.setMessageListener(this);

         //***** Step 3: Prepare request

         m.setJMSReplyTo(replyD);

         m.setJMSCorrelationID(id);

         //***** Step 4: Create producer and send request

         MessageProducer p= s.createProducer(reqD);

         p.send(m);
         p.close();
      }
      catch(JMSException jmsx) { System.out.println(jmsx); }
      return id;
   }


   public void onMessage(Message m)
   {
      try {
         //***** Step 5: Id from incoming reply become hash table key

         String id= m.getJMSCorrelationID();
         replyTable.put(id, m);
      }
      catch(JMSException jmsx) { System.out.println(jmsx); }
      V();
   }

/**
 * Abandons pending requests.
 */
   public Hashtable quit() { finalize(); return replyTable; }

   protected void finalize()
   {
      for  (Enumeration e= consumerTable.elements(); e.hasMoreElements();)
      {
         MessageConsumer c= (MessageConsumer)e.nextElement();
         try { c.close(); }
         catch(JMSException jmsx) { System.out.println(jmsx); }
      }
   }
}
