// TIBCO Enterprise for JMS
// TIBCO Education Services
// Copyright 2003 - TIBCO Software Inc.
// ALL RIGHTS RESERVED

import javax.naming.*;
import javax.jms.*;

public class Server
{
	public static void main(String[] args)
	{
		String 				destName = null;
		Context 				jndiContext = null;
		ConnectionFactory			cFactory = null;
		Connection				conn = null;
		Session				session = null;
		Destination 			myDest=null;
		TextMessage				msg = null;
		MessageConsumer			myCons = null;
		MessageProducer			myProd = null;

		if (args.length !=1)
		{
			System.out.println("Usage: java Server " + "<destination-name>");
			System.exit(1);
		}

		destName = new String(args[0]);
		System.out.println("Listening destination: "+ destName);

		try
		{
                        // ***** Step 5: No-arg constructor
			jndiContext = new InitialContext();
			cFactory = (ConnectionFactory)jndiContext.lookup("ConnectionFactory");

			myDest = (Destination)jndiContext.lookup(destName);
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}

		try
		{
			conn = cFactory.createConnection();
			session = conn.createSession(false,Session.AUTO_ACKNOWLEDGE);
			myCons = session.createConsumer(myDest);
			myProd = session.createProducer(null);
			conn.start();

//			while (true)
			{
				Message inMsg = myCons.receive(3000);
				if  (inMsg == null)
					System.out.println("Waiting for a request...");
				else
				{
                             Destination replyDestination= inMsg.getJMSReplyTo();

					if (inMsg instanceof TextMessage)
					{
						msg = (TextMessage)inMsg;
						System.out.println("Received: " + msg.getText());                                    
					}

                             if  (replyDestination != null) {
                                   Message outMsg= session.createTextMessage("UserXX time: " + new java.util.Date());

                                   // ***** Step 6: Set the reply's JMSCorrelationID to match the request

                                   outMsg.setJMSCorrelationID(inMsg.getJMSCorrelationID());

                                   System.out.println("Sending reply " + outMsg + " to " + replyDestination);
                                   myProd.send(replyDestination, outMsg);
                             }
                             else
					{
						System.out.println("No reply destination in message: " + inMsg);
//						break;
					}
				}
			}
		}
		catch (JMSException e)
		{
			System.out.println("Exception in receive message  :" + e.toString());
			System.exit(1);
		}
		finally
		{
			if (conn != null)
			try
			{
				conn.close();
			}
			catch(JMSException e)
			{
				System.out.println("Exception:" + e.toString());
			}
		}
	}
}
