////////////////////////////////////////////////////
// TIBCO Enterprise for JMS - JAVA API
// File: SimpleProd.java
// TIBCO Education Services
// Copyright 2003 - TIBCO Software Inc.
// ALL RIGHTS RESERVED
////////////////////////////////////////////////////

// Step 1. Import the necessary Jars
import javax.jms.*;
import javax.naming.*;
import java.util.Hashtable;

public class SimpleProd
{
    // Step 2: Fill in the provider context factory and the provider URL
    static final String  providerContextFactory =
                            "com.tibco.tibjms.naming.TibjmsInitialContextFactory";
    static final String  providerURL ="tibjmsnaming://localhost:7222";

	public static void main(String[] args)
	{
		String 					topicName = null;
		Context 				jndiContext = null;
		ConnectionFactory		cFactory = null;
		Connection				conn = null;
		Session					session = null;
		Destination 			myDest=null;
		MessageProducer			myProd = null;
		TextMessage				msg = null;

		if (args.length!=2)
		{
			System.out.println("Usage: java SimpleProd <Topic> <message>");
			System.exit(1);
		}

		topicName = new String(args[0]);
		System.out.println("Topic is:"+ topicName);


		// **** Step 3 Get initial Context
		try
		{
			Hashtable env = new Hashtable();
			env.put(Context.INITIAL_CONTEXT_FACTORY,providerContextFactory);
			env.put(Context.PROVIDER_URL,providerURL);
    		jndiContext = new InitialContext(env);

			// **** Step 4 create connection factory
    		cFactory = (ConnectionFactory)jndiContext.lookup("ConnectionFactory");
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}


		try
		{
			// **** Step 5 Create Connection, Session
			conn = cFactory.createConnection();
			session = conn.createSession(false,Session.AUTO_ACKNOWLEDGE);

			// **** Step 6 lookup topic
			myDest = (Destination)jndiContext.lookup(topicName);

			// **** Step 7 Create Producer
			myProd = session.createProducer(myDest);

			// **** Step 8 Create Text Message
			msg = session.createTextMessage();

			msg.setText(args[1]);
			System.out.println("Sending " + msg.getText());

			// **** Step 9 Send message
			myProd.send(msg);
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}
		catch (JMSException e)
		{
			System.out.println("Exception in send message :" + e.toString());
			System.exit(1);
		}
		finally
		{
			if (conn != null)
			try
			{
				// **** Step 10 Close the connection
				conn.close();
			}
			catch(JMSException e)
			{
				System.out.println("Exception:" + e.toString());
			}
		}
	}
}

