// TIBCO Enterprise for JMS
// TIBCO Education Services
// Copyright 2003 - TIBCO Software Inc.
// ALL RIGHTS RESERVED

import javax.naming.*;
import javax.jms.*;
import java.util.Hashtable;

public class Server
{
	static final String  providerContextFactory =
			                            "com.tibco.tibjms.naming.TibjmsInitialContextFactory";
	static final String  providerURL ="tibjmsnaming://localhost:7222";

	public static void main(String[] args)
	{
		String 				destName = null;
		Context 				jndiContext = null;
		ConnectionFactory			cFactory = null;
		Connection				conn = null;
		Session				session = null;
		Destination 			myDest=null;
		TextMessage				msg = null;
		MessageConsumer			myCons = null;
		MessageProducer			myProd = null;

		if (args.length !=1)
		{
			System.out.println("Usage: java Server " + "<destination-name>");
			System.exit(1);
		}

		destName = new String(args[0]);
		System.out.println("Listening destination: "+ destName);

		try
		{
			Hashtable env = new Hashtable();
			env.put(Context.INITIAL_CONTEXT_FACTORY,providerContextFactory);
			env.put(Context.PROVIDER_URL,providerURL);
			jndiContext = new InitialContext(env);
			cFactory = (ConnectionFactory)jndiContext.lookup("ConnectionFactory");

			myDest = (Destination)jndiContext.lookup(destName);
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}

		try
		{
			conn = cFactory.createConnection();
			session = conn.createSession(false,Session.AUTO_ACKNOWLEDGE);

			// ***** Step 1: Create the consumer
			myCons = session.createConsumer(myDest);

			// ***** Step 2: Create the producer with an undefined destination
			myProd = session.createProducer(null);

			conn.start();

			while (true)
			{
				// ***** Step 3: Wait for at most 3 seconds to receive the message
				Message inMsg = myCons.receive(3000);
				if  (inMsg == null)
					System.out.println("Waiting for a request...");
				else
				{
                             // ***** Step 4: Extract the reply destination
                             Destination replyDestination= inMsg.getJMSReplyTo();

					if (inMsg instanceof TextMessage)
					{
						msg = (TextMessage)inMsg;
						System.out.println("Received: " + msg.getText());                                    
					}

                             // ***** Step 5: Test for non-null reply destination
                             if  (replyDestination != null) {

                             // ***** Step 6:  Compute reply, substituting your digits for XX
                                   Message outMsg= session.createTextMessage("UserXX time: " + new java.util.Date());

                             // ***** Step 7: Send reply message to  reply destination
						System.out.println("Sending reply " + outMsg + " to " + replyDestination);
                                   myProd.send(replyDestination, outMsg);
                             }
                             else
					{
						System.out.println("No reply destination in message: " + inMsg);
						break;
					}
				}
			}
		}
		catch (JMSException e)
		{
			System.out.println("Exception in receive message  :" + e.toString());
			System.exit(1);
		}
		finally
		{
			if (conn != null)
			try
			{
				conn.close();
			}
			catch(JMSException e)
			{
				System.out.println("Exception:" + e.toString());
			}
		}
	}
}
