////////////////////////////////////////////////////
// TIBCO Enterprise for JMS - JAVA API
// File: PriorityProd.java
// TIBCO Education Services
// Copyright 2003 - TIBCO Software Inc.
// ALL RIGHTS RESERVED
////////////////////////////////////////////////////

import javax.jms.*;
import javax.naming.*;
import java.util.Hashtable;

public class PriorityProd
{
    static final String  providerContextFactory =
                            "com.tibco.tibjms.naming.TibjmsInitialContextFactory";
    static final String  providerURL ="tibjmsnaming://localhost:7222";

	public static void main(String[] args)
	{
		String 				queueName = null;
		Context 				jndiContext = null;
		ConnectionFactory			cFactory = null;
		Connection				conn = null;
		Session				session = null;
		Destination 			myDest=null;
		MessageProducer			myProd = null;
		TextMessage				msg = null;

		if (args.length <1)
		{
			System.out.println("Usage: java PriorityProd <queuename>");
			System.exit(1);
		}

		queueName = new String(args[0]);
		System.out.println("Queue is:"+ queueName);

		try
		{
			Hashtable env = new Hashtable();
			env.put(Context.INITIAL_CONTEXT_FACTORY,providerContextFactory);
			env.put(Context.PROVIDER_URL,providerURL);
	    		jndiContext = new InitialContext(env);
	    		cFactory = (ConnectionFactory)jndiContext.lookup("ConnectionFactory");
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}

		try
		{
			conn = cFactory.createConnection();
			session = conn.createSession(false,Session.AUTO_ACKNOWLEDGE);
			myDest = (Destination)jndiContext.lookup(queueName);
			myProd = session.createProducer(myDest);
			msg = session.createTextMessage();

			for  (int priority= 0;  priority < 10;  ++priority) {
                       int    msgCount= priority+1;
				String urgency=  priority > 5 ? "high" : "low";

				// ***** Step 1: Set String property URGENCY
				msg.setStringProperty("URGENCY", urgency);

				// ***** Step 2: Set message priority
				myProd.setPriority(priority);

				// ***** Step 3: Set Text of Text Message
				msg.setText("Sent " + msgCount + " with priority " + priority);

				System.out.println(msg.getText());
				myProd.send(msg);
			}
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}
		catch (JMSException e)
		{
			System.out.println("Exception in send message :" + e.toString());
			System.exit(1);
		}
		finally
		{
			if (conn != null)
			try
			{
				conn.close();
			}
			catch(JMSException e)
			{
				System.out.println("Exception:" + e.toString());
			}
		}
	}
}
