// TIBCO Enterprise for JMS
// File: QueueBrowser.java
// TIBCO Education Services
// Copyright 2003 - TIBCO Software Inc.
// ALL RIGHTS RESERVED

// ***** Step 1: Import the Jars
import javax.naming.*;
import javax.jms.*;
import java.util.Hashtable;
import java.util.Enumeration;

public class QueueBrowser
{
	// ***** Step 2: Provide the correct values
	static final String  providerContextFactory =
			                            "com.tibco.tibjms.naming.TibjmsInitialContextFactory";
	static final String  providerURL ="tibjmsnaming://localhost:7222";

	public static void main(String[] args)
	{
		String 					topicName = null;
		Context 				jndiContext = null;
		ConnectionFactory		cFactory = null;
		Connection				conn = null;
		Session					session = null;
		Queue					myDest=null;
		TextMessage				msg = null;
		javax.jms.QueueBrowser	myBrowser = null;

		if (args.length !=1)
		{
			System.out.println("Usage: java SimpleCons " + "<topic-name>");
			System.exit(1);
		}

		topicName = new String(args[0]);
		System.out.println("Listening on Topic : "+ topicName);


		// ***** Step 3: Get initial Context, create connection factory
		try
		{
			Hashtable env = new Hashtable();
			env.put(Context.INITIAL_CONTEXT_FACTORY,providerContextFactory);
			env.put(Context.PROVIDER_URL,providerURL);
			jndiContext = new InitialContext(env);
			cFactory = (ConnectionFactory)jndiContext.lookup("ConnectionFactory");

			// ***** Step 4: Lookup the Topic
			myDest = (Queue)jndiContext.lookup(topicName);
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}

		try
		{
			// ***** Step 5: Create the connection and the session
			conn = cFactory.createConnection();
			session = conn.createSession(false,Session.AUTO_ACKNOWLEDGE);

			// ***** Step 6: Create the subscriber
			myBrowser = session.createBrowser(myDest);

			// ***** Step 7: Start the connection
			conn.start();
			Enumeration enum = myBrowser.getEnumeration();

			int i = 0;
			while (enum.hasMoreElements())
			{
				i = i + 1;
				Message inMsg = (Message)enum.nextElement();
				if  (inMsg != null)
				{
					// ***** Step 9: Check if it is a Text Message, and cast it
					if (inMsg instanceof TextMessage)
					{
						msg = (TextMessage)inMsg;
						System.out.println("Message no: " + i + " " + msg.getText());
					}
					else
					{
						System.out.println("Exiting Program" + inMsg);
						break;
					}
				}
			}
		}
		catch (JMSException e)
		{
			System.out.println("Exception in receive message  :" + e.toString());
			System.exit(1);
		}
		finally
		{
			if (conn != null)
			try
			{
				conn.close();
			}
			catch(JMSException e)
			{
				System.out.println("Exception:" + e.toString());
			}
		}
	}
}

