/* 
 * Copyright(c) 2001 TIBCO Software Inc. 
 * All rights reserved.
 * For more information, please contact:
 * TIBCO Software Inc., Palo Alto, California, USA
 * Written By : Kiet Duong
 * History : 
 *  Written Date : Nov 2001 
 */

/*
 * CreditUtil.java
 * DESCRIPTION : An object utility that insulated the work required to perform
 *               the validation of a credit card and its credit limit for a customer request by
 *               executing the following steps:
 *               Connect to the Credit System
 *               Receives credit information via function parameters
 *               Perform the validation for the credit card
 *               Package the result of the validation into an xml document
 *
 */

import java.io.*;
import com.tibco.tibchoc.*;

public class CreditUtil
{
    private String _creditFilename = new String();
    private CreditSystem _cs = null;
    
    public CreditUtil(String creditFilename) throws ClassNotFoundException, IOException
    {
        _creditFilename = creditFilename;
        _cs = new CreditSystem(_creditFilename);
    }
    
    public String checkCreditCard(String orderID, String creditCardNumber, String creditCardType, double purchaseAmount) throws Exception
    {
        String returnVal = new String();
        DomDocOut cDom = new DomDocOut();
        cDom.createRoot("Reply");
        cDom.add("OrderID", orderID);

		
		System.out.println("Inside CheckCreditCard()...");
        if (_cs.checkIfCreditExists(creditCardNumber, creditCardType)) 
        {
			System.out.println("CheckCreditCard(): Credit card exist...");
            if (_cs.getCreditLimitBalance(creditCardNumber, creditCardType)>purchaseAmount)
            {
                cDom.add("Status","SUCCESS");
                cDom.add("Detail","");
			    System.out.println("CheckCreditCard(): Credit card exist and credit limit is OKAY...");
            }
            else
            {
                cDom.add("Status","UNSUCCESS");

                String msg = new String();
                msg += "Sorry, we could not process your transaction because of the following reason.<BR>";
                msg += "Exceed credit card limit.<BR>";
                msg += "Current limit: $";
                msg += _cs.getCreditLimitBalance(creditCardNumber, creditCardType);
                msg += "<BR>";
                msg += "Requested amount: $";
                msg += purchaseAmount;
                msg += "<BR>";
                cDom.add("Detail",msg);
			    System.out.println("CheckCreditCard(): Credit card exist but exceed credit limit...");
            }
        }
        else
        {
            cDom.add("Status","UNSUCCESS");

            String msg = new String();
            msg += "Sorry, we could not process your transaction because of the following reason.<BR>";
            msg += "Invalid credit card: " + creditCardNumber;
            cDom.add("Detail",msg);
			System.out.println("CheckCreditCard(): Invalid credit card...");
        }
        returnVal = cDom.toString();
        return returnVal;
    }
}