/* 
 * Copyright(c) 2001 TIBCO Software Inc. 
 * All rights reserved.
 * For more information, please contact:
 * TIBCO Software Inc., Palo Alto, California, USA
 * Written By : Medha Samant
 * History : 
 *  Written Date : Nov 2001 
 */
/*
 * InventoryReplyMsgListener.java
 * DESCRIPTION : Receives message on inventory reply queue
 *               Parses the message and updates inMemoryHash accordingly
 *
 */

import javax.jms.*;
import javax.naming.*;
import java.util.*;
import com.tibco.tibchoc.*;

   
   
class InventoryReplyMsgListener implements MessageListener
{
    private String _debug;
    private BusinessProcessCoordinator _jbpc;
        
        
    public InventoryReplyMsgListener(BusinessProcessCoordinator bpcObject)
    {
            _debug = "true";
            _jbpc = bpcObject;
    }
        
    public void onMessage(Message message) 
    {
        try
        {
            System.out.println("JBPC : inventoryMsgListener : received reply on inventoryReplyQueue "); 
            if(_debug.equalsIgnoreCase("TRUE"))
                    System.out.println("Reply from inventory : " + message.toString());
            processReply(message);
        }
        catch(Exception e) 
        {
            System.out.println("Exception : " + e.toString());
            System.exit(0);
        }
    }

    public void processReply(Message message)
    {
        InMemoryStructure memStruct;
        try
        {
            //Parse message
            if(_debug.equalsIgnoreCase("TRUE"))
                System.out.println("JBPC : Inside processInventoryReply ");
            DomDoc xmlDoc = new DomDoc(((TextMessage)message).getText());
            xmlDoc.parse();
            String orderid = xmlDoc.get("OrderID");
            String invchkStatus = xmlDoc.get("Status");
            //set Status and Details
                
            String retInvStatus = new String();
            String retInvDetail = new String();
                
            if(invchkStatus.equalsIgnoreCase("SUCCESS"))
                    retInvStatus = "SUCCESS";
            else 
            {
                retInvStatus = "UNSUCCESS";
                retInvDetail = xmlDoc.get("Detail");
            }
                
            synchronized(this)
            {
                Hashtable hash = OrderHash.getHashInstance();
                memStruct = (InMemoryStructure)hash.get(orderid);
                memStruct.setInventoryCheck(retInvStatus, retInvDetail);
                hash.put(orderid, memStruct);
            }
            //Check if reply from credit check is received
            if(memStruct.getCreditStatus() != null)
            {
                if(_debug.equalsIgnoreCase("TRUE"))
                    System.out.println("JBPC : Done with order id " + orderid);
                _jbpc.sendReplyToWeb(orderid);
            }
        }
        catch(Exception e)
        {
            System.out.println(e.toString());
            System.exit(0);
        }
    }
}