/* 
 * Copyright(c) 2001 TIBCO Software Inc. 
 * All rights reserved.
 * For more information, please contact:
 * TIBCO Software Inc., Palo Alto, California, USA
 * Written By : Medha Samant
 * History : 
 *  Written Date : Nov 2001 
 */
/* 
 * Lab G Exercise 3: Sub Order Procesing Adapter
 * Step 1 to 9.
 */
/*
 * SubOrderProcessAdapter.java
 * DESCRIPTION : Can act as adapter to enter order into Order databse.
 *               Currently it just receives message on a topic and consumes it using following steps:
 *               Creates durable subscriber on a topic
 *               Receives message on the topic 
 *
 */

import com.tibco.tibchoc.*;

// Step 1: Import the entire javax.jms package
import javax.jms.*;


public class SubOrderProcessAdapter implements MessageListener
{
    private String _serverName;
    private String _destinationName;
    private String _propertiesFileName;
    private String _debug = "false";
    private String _user;
    private String _password;
    private String _factoryName;
    private String _subscriberName;

    private Connection      _Connection = null;
    private Session         _Session;
    private TopicSubscriber _Subscriber;
    private Destination     _Dest;    

    public SubOrderProcessAdapter (String propertiesFileName) throws Exception
    {
        _propertiesFileName = propertiesFileName;
    }

    public void init() throws Exception 
    {
        try
        {
            System.out.println("Order Entry Adapter[" + _serverName + "] Starting up....");

            AppProperties.loadProperties(_propertiesFileName);
            _serverName         = AppProperties.getProperty("TIBCHOC.serverName");
            _debug              = AppProperties.getProperty("TIBCHOC.debug");
            _destinationName    = AppProperties.getProperty("TIBCHOC.receiveDestination");
            _user               = AppProperties.getProperty("TIBCHOC.user");
            _password           = AppProperties.getProperty("TIBCHOC.password");
            _factoryName        = AppProperties.getProperty("TIBCHOC.factory");
            _subscriberName     = AppProperties.getProperty("TIBCHOC.durableSubscriber");
            openJMSConnection();
        }
        catch(Exception e)
        {
            System.out.println(e.toString());
        }
    }

    public void openJMSConnection()
    {
        try 
        {
        TibjmsUtilities.initJNDI(_serverName);

        // Step 2: Use the JNDI to obtain a connection factory
        ConnectionFactory factory =
                (ConnectionFactory)TibjmsUtilities.lookup(_factoryName);

        // Step 3: Create a connnection using the connection factory
        _Connection = factory.createConnection(_user,_password);

        // Step 4: Create a session using the connection
        _Session = _Connection.createSession(false,Session.AUTO_ACKNOWLEDGE);

        // Step 5: Obtain a specific destination
        _Dest = (Destination)TibjmsUtilities.lookup(_destinationName);

        // Step 6: Create a durable subscriber
        _Subscriber = _Session.createDurableSubscriber((Topic)_Dest, _subscriberName);

        System.out.println("Inventory Update Adapter : Created Durable Subscriber: " + _subscriberName);
        _Subscriber.setMessageListener(this);

        // Step 7: Start a connection
        _Connection.start();
             synchronized (this) 
             {
                try 
                {
                    this.wait();
                } 
                catch (InterruptedException ie) {}
             }
        }
        catch(Exception e)
        { 
            System.out.println(e.toString());
            System.exit(0);
        }
    }

    // Step 8: Receive asynchronous delivered message
    public void onMessage(Message message) 
    {
		System.out.println("Order Entry Adapter : Received Message ");
        if(_debug.equalsIgnoreCase("TRUE"))
		    System.out.println("MESSAGE : " + message.toString());
    } 
    
    public void closeConnection()
    {
        try
        {
            if (_Connection!=null)
            {
                // Step 9: Close the connection
                _Connection.close();
                _Connection = null;
            }
        }
        catch(JMSException e)
        {
            e.printStackTrace();
        }
    }

    public static void main(String args[]) 
    {
        try 
        {
             SubOrderProcessAdapter oEntAda= new SubOrderProcessAdapter(args[0]);
             oEntAda.init();
        }
        catch (Exception e) 
        {
            e.printStackTrace();
        }       
    }
}
    
