/*
 * Lab E: JMS Client for the servlet
 * Step 1 to 9.
 */

/*
 * JMSClient.java
 * DESCRIPTION : JMS client to interact with the JMS BPC via a synchronous communication (ie. a blocking request/reply call)
 *
 *
 */

import com.tibco.tibchoc.AppProperties;

// Step 1: Import the entire javax.jms package
import javax.jms.*;

public class JMSClient
{
    private String _propertiesFileName;
    private String _serverName;
    private String _debug;
    private String _user;
    private String _password;

    private ConnectionFactory _qFactory;
    private Connection _qConnection;
    private QueueSession _qSession;

    private QueueRequestor webRequestor;
    private TextMessage _message;

    public JMSClient(String fileName) throws Exception
    {
        _propertiesFileName = new String(fileName);
    }

    public void init() throws Exception
    {
        //Initialized the JMS Web Client
        AppProperties.loadProperties(_propertiesFileName);
        _serverName    = AppProperties.getProperty("TIBCHOC.serverName");
        _debug         = AppProperties.getProperty("TIBCHOC.debug");
        _user          = AppProperties.getProperty("TIBCHOC.user");
        _password      = AppProperties.getProperty("TIBCHOC.password");
        openJMSConnection();
    }

    public void openJMSConnection() throws Exception, JMSException
    {
        // Using JNDI to connect to the JMS server
        TibjmsUtilities.initJNDI(_serverName);

        // Step 2: Use JNDI to obtain a connection factory
        _qFactory = (ConnectionFactory)TibjmsUtilities.lookup("QueueConnectionFactory");

        // Step 3: Create a connection using the connection factory
        _qConnection = _qFactory.createConnection(_user,_password);

        // Step 4: Create a session using the connection
        _qSession = ((QueueConnection)_qConnection).createQueueSession(false,Session.AUTO_ACKNOWLEDGE);

        //setup a request web sender (queue-based)
        String queueName = AppProperties.getProperty("TIBCHOC.sendDestination");

        // Step 5: Obtain a specified queue
        Queue webSendQueue = (Queue)TibjmsUtilities.lookup(queueName);
        // Step 6: Create a requestor

        webRequestor = new QueueRequestor(_qSession, webSendQueue);

        // Step 7: Activate a connection
        _qConnection.start();
    }

    public void sendXMLMessage(String xmlDoc) throws Exception, JMSException
    {
        // Compose a JMS message with the content of the message as a xml document
        // and then make a synchronous communication (ie. blocking request) to the
        // BPC.
        TextMessage xmlMessage = _qSession.createTextMessage();
        xmlMessage.setText(xmlDoc);

        // Step 8: Send and receive message
        _message = (TextMessage)webRequestor.request(xmlMessage);
    }

    public String getReplyXMLDoc() throws JMSException
    {
        String result = new String("XML Documents");
        if (_message!=null)
        {
            result = _message.getText();
        }
        return result;
    }

    private void closeConnection() throws JMSException
    {
        // Step 9: Close the session and connection
        if (_qConnection!=null)
            _qConnection.close();
        _qConnection = null;
    }

    public void finalize() throws Exception, JMSException
    {
        closeConnection();

    }

    public static void main(String args[]){
		try{
		JMSClient c = new JMSClient(args[0]);
		c.init();
		}catch (Exception e){
			e.printStackTrace();
		}
	}
}
