/*
 * Copyright(c) 2001 TIBCO Software Inc.
 * All rights reserved.
 * For more information, please contact:
 * TIBCO Software Inc., Palo Alto, California, USA
 * Written By : Kiet Duong
 * History :
 *  Written Date : Nov 2001
 */

/*
 * JMSClientServlet.java
 * DESCRIPTION : A servlet to perform the following steps:
 *               Generate a unique ID for OrderID
 *               Compute the total amount for the order, included shipping and tax.
 *               Generate an xml document
 *               Send a JMS message using synchronous request/reply communication
 *               Generate a HTML page for the web front end to display the result
 *
 */

import java.io.*;
import java.rmi.server.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.tibco.tibchoc.*;

public class JMSClientServlet extends DoGetPostServlet
{
    private double m_totalCharge = 0.00;      // Total amount for the ordered items
    private double m_shippingFee = 15.00;     // USD 15.00
	private double m_tax = 0.10;              // 10 percent for tax

	protected void doGetPost(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException
	{
		res.setContentType("text/html");
		PrintWriter out = res.getWriter();

		String xmlDoc = new String("testing 1 2 3");

        try
        {
		    xmlDoc = buildXMLDoc(req);

            JMSClient jClient = new JMSClient("servlet.cfg");
            jClient.init();
            jClient.sendXMLMessage(xmlDoc);
            xmlDoc = jClient.getReplyXMLDoc();

		    String title = "TIBCHOC Online 'chocolate in real time'";
		    respond2Web(out, xmlDoc, title);
        }
        catch (Exception e)
        {
		    wrapInHtmlPage(out, e.toString(), "Order processing is temporary out of action!!!");
        }
	}

    protected void respond2Web(PrintWriter out, String queryResult, String title) throws IOException
    {
        String result = new String();
        try
        {
            DomDoc msgFromBPC = new DomDoc(queryResult);
            msgFromBPC.parse();
            if ((msgFromBPC.get("Status")).equalsIgnoreCase("SUCCESS"))
            {
                String message = "<font size=\"4\"><i>Thanks for placing your business with TIBCHOC. <BR>";
                message += "Here is your receipt number: " + msgFromBPC.get("OrderID");
                message += "<BR>Enjoy our delicious chocolates...<BR></font>";
                wrapInHtmlPage(out, message, title);
            }
            else
            {
                // unsuccessfull
                wrapInHtmlPage(out, msgFromBPC.get("Detail"), title);
            }
        }
        catch(Exception e)
        {
		    wrapInHtmlPage(out, e.toString(), "Order process is temporary out of action!!!");
        }
    }

	protected void wrapInHtmlPage(PrintWriter out, String queryResult, String title)throws IOException
	{
		out.println("<HTML><HEAD><TITLE> " + title + "</TITLE></HEAD>");
		out.println("<BODY><H1>" + title + "</H1>");
		out.println(queryResult);
		out.println("</BODY></HTML>");
	}

    protected String buildXMLDoc(HttpServletRequest req) throws Exception
    {
        String xmlDoc = new String();
        xmlDoc = buildXMLHeader();
        xmlDoc += "<Order>";
        xmlDoc += buildOrderID(req);
        xmlDoc += buildPersonalInfo(req);
        xmlDoc += buildCreditInfo(req);
        xmlDoc += buildShippingAddress(req);
        xmlDoc += buildOrderItems(req);
        xmlDoc += buildTotalCharge(req);
        xmlDoc += "</Order>";
        return xmlDoc;
    }

    protected String buildXMLHeader()
    {
        return new String("<?xml version='1.0' encoding='UTF-8'?>");
    }

    protected String buildOrderID(HttpServletRequest req) throws Exception
    {
        return addElement("OrderID", generateOrderID());
    }

    protected String generateOrderID() throws Exception
    {
        String generateOrderID = new String("TIBCHOC-");
        generateOrderID += (new UID()).toString();
        return generateOrderID;
    }

    protected String buildPersonalInfo(HttpServletRequest req) throws Exception
    {
        String personalInfo = new String("<PersonalInformation>");
        personalInfo += addElement("FName", req.getParameter("FName"));
        personalInfo += addElement("LName", req.getParameter("LName"));
        personalInfo += addElement("WPhone", req.getParameter("WPhone"));
        personalInfo += addElement("HPhone", req.getParameter("HPhone"));
        personalInfo += addElement("EMail", req.getParameter("EMail"));
        personalInfo += "</PersonalInformation>";
        return personalInfo;
    }

    protected String buildCreditInfo(HttpServletRequest req) throws Exception
    {
        String creditInfo = new String("<CreditInformation>");
        creditInfo += addElement("CCNumber", req.getParameter("CCNumber"));
        creditInfo += addElement("CCType", req.getParameter("CCType"));
        creditInfo += addElement("EDate", req.getParameter("EDate"));
        creditInfo += buildCreditAddress(req);
        creditInfo += "</CreditInformation>";
        return creditInfo;
    }

    protected String buildCreditAddress(HttpServletRequest req) throws Exception
    {
        String creditAddress = new String("<Address>");
        creditAddress += addElement("Street", req.getParameter("Street"));
        creditAddress += addElement("City", req.getParameter("City"));
        creditAddress += addElement("State", req.getParameter("State"));
        creditAddress += addElement("Zip", req.getParameter("Zip"));
        creditAddress += "</Address>";
        return creditAddress;
    }

    protected String buildShippingAddress(HttpServletRequest req) throws Exception
    {
        String shippingAddress = new String();
        if (!(req.getParameter("Street2")).equals(""))
        {
            shippingAddress = "<ShippingInformation>";
            shippingAddress += "<Address>";
            shippingAddress += addElement("Street", req.getParameter("Street2"));
            shippingAddress += addElement("City", req.getParameter("City2"));
            shippingAddress += addElement("State", req.getParameter("State2"));
            shippingAddress += addElement("Zip", req.getParameter("Zip2"));
            shippingAddress += "</Address>";
            shippingAddress += "</ShippingInformation>";
        }
        return shippingAddress;
    }

    protected String buildOrderItems(HttpServletRequest req) throws Exception
    {
        String orderItems = new String("<OrderItems>");

        m_totalCharge = 0.00;
        if (req.getParameter("AC")!=null && Integer.parseInt(req.getParameter("AC"))>0)
        {
            m_totalCharge += (Double.parseDouble(req.getParameter("AC")))*35;
	        orderItems += addOrderItem("Assorted Chocolates", req.getParameter("AC"));
	    }
        if (req.getParameter("MC")!=null && Integer.parseInt(req.getParameter("MC"))>0)
        {
            m_totalCharge += (Double.parseDouble(req.getParameter("MC")))*25;
	        orderItems += addOrderItem("Milk Chocolates", req.getParameter("MC"));
        }
        if (req.getParameter("DC")!=null && Integer.parseInt(req.getParameter("DC"))>0)
        {
            m_totalCharge += (Double.parseDouble(req.getParameter("DC")))*26.95;
	        orderItems += addOrderItem("Dark Chocolates", req.getParameter("DC"));
        }
        if (req.getParameter("CWN")!=null && Integer.parseInt(req.getParameter("CWN"))>0)
        {
            m_totalCharge += (Double.parseDouble(req.getParameter("CWN")))*38;
	        orderItems += addOrderItem("Chocolates with Nuts", req.getParameter("CWN"));
        }
        if (req.getParameter("WC")!=null && Integer.parseInt(req.getParameter("WC"))>0)
        {
            m_totalCharge += (Double.parseDouble(req.getParameter("WC")))*18;
	        orderItems += addOrderItem("White Chocolates", req.getParameter("WC"));
        }
        if (req.getParameter("CT")!=null && Integer.parseInt(req.getParameter("CT"))>0)
        {
            m_totalCharge += (Double.parseDouble(req.getParameter("CT")))*40;
	        orderItems += addOrderItem("Chocolates Truffles", req.getParameter("CT"));
        }
        if (req.getParameter("SCC")!=null && Integer.parseInt(req.getParameter("SCC"))>0)
        {
            m_totalCharge += (Double.parseDouble(req.getParameter("SCC")))*25;
	        orderItems += addOrderItem("Soft Center Chocolates", req.getParameter("SCC"));
        }
	    orderItems += "</OrderItems>";
	    return orderItems;
    }

    protected String buildTotalCharge(HttpServletRequest req) throws Exception
    {
        return addElement("TotalCharge", calcTotalCharge(req));
    }

    protected String calcTotalCharge(HttpServletRequest req) throws Exception
    {
        // tax: 10%
        // shipping fee = $15
        double taxAmount = m_totalCharge*m_tax;
        m_totalCharge += taxAmount;
        m_totalCharge += m_shippingFee;
        return new String(Double.toString(m_totalCharge));
    }

    protected String addOrderItem(String itemName, String quantity) throws Exception
    {
        String orderItem = new String("<Items>");
        orderItem += addElement("ItemName", itemName);
        orderItem += addElement("Quantity", quantity);
        orderItem += "</Items>";
        return orderItem;
    }

	protected String addElement(String elementName, String value) throws Exception
	{
	    String sData = new String("<" + elementName + ">" + value + "</" + elementName + ">");
	    return sData;
	}
}
