
/* 
 * Copyright(c) 2002 TIBCO Software Inc. 
 * All rights reserved.
 * For more information, please contact:
 * TIBCO Software Inc., Palo Alto, California, USA
 * 
 * $RCSfile: tibjmsUtilities.java,v $
 * $Revision: 1.3 $
 * $Date: 2001/05/30 02:34:29 $
 */

/*
 * This sample uses JNDI to retrieve administered objects.
 *
 * Optionally all parameters hardcoded in this sample can be 
 * read from the jndi.properties file.
 *
 */

import java.util.Hashtable;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;


public class TibjmsUtilities
{
    static Context jndiContext = null;
    
    static final String  providerContextFactory = "com.tibco.tibjms.naming.TibjmsInitialContextFactory";
                            
    static final String  defaultProviderURL = "tibjmsnaming://localhost:7222";
                            
    public static void initJNDI(String providerURL) throws NamingException 
    {
        if (jndiContext != null)
            return;
            
        if (providerURL == null || (providerURL.length() == 0))
            providerURL = defaultProviderURL;
        
        try 
        {
            Hashtable env = new Hashtable();
            env.put(Context.INITIAL_CONTEXT_FACTORY,providerContextFactory);
            env.put(Context.PROVIDER_URL,providerURL);
            	    
            jndiContext = new InitialContext(env);
        } 
        catch (NamingException e) 
        {
            System.out.println("Failed to create JNDI InitialContext with provider URL set to "+
	                            providerURL+", error = "+e.toString());
            throw e;
        }
    }
        
    public static Object lookup(String objectName) throws NamingException
    {
        if (objectName == null)
            throw new IllegalArgumentException("null object name not legal");
        
        if (objectName.length() == 0)
            throw new IllegalArgumentException("empty object name not legal");
        
        /* 
         * check if not initialized, then initialize
         * with default parameters
         */
        initJNDI(null);
        
        /*
         * do the lookup
         */
	    return jndiContext.lookup(objectName);
    }
}


