// TIBCO Enterprise for JMS
// File: AsyncCons.java
// TIBCO Education Services
// Copyright 2003 - TIBCO Software Inc.
// ALL RIGHTS RESERVED

// ***** Step 1: Import the Jars
import javax.naming.*;
import java.util.Hashtable;
import javax.jms.*;

public class AsyncCons
{
	// ***** Step 2: Provide the correct values
	static final String  providerContextFactory = "com.tibco.tibjms.naming.TibjmsInitialContextFactory";
	static final String  providerURL ="tibjmsnaming://localhost:7222";

	public static void main(String[] args)
	{
		String 					topicName = null;
		Context 				jndiContext = null;
		ConnectionFactory		cFactory = null;
		Connection				conn = null;
		Session					session = null;
		Destination 			myDest=null;
		TextMessage				msg = null;
		MessageConsumer			asyncCons = null;

		if (args.length !=1)
		{
			System.out.println("Usage: java SimpleCons " + "<topic-name>");
			System.exit(1);
		}

		topicName = new String(args[0]);
		System.out.println("Listening on Topic : "+ topicName);


		// ***** Step 3: Get initial Context, create connection factory
		try
		{
			Hashtable env = new Hashtable();
			env.put(Context.INITIAL_CONTEXT_FACTORY,providerContextFactory);
			env.put(Context.PROVIDER_URL,providerURL);
			jndiContext = new InitialContext(env);
			cFactory = (ConnectionFactory)jndiContext.lookup("TopicConnectionFactory");

			// ***** Step 4: Lookup the Topic
			myDest = (Destination)jndiContext.lookup("USERSA.TOPIC");
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}

		try
		{
			// ***** Step 5: Create the connection and the session
			conn = cFactory.createConnection();
			session = conn.createSession(false,Session.AUTO_ACKNOWLEDGE);

			// ***** Step 6: Create the subscriber
			asyncCons = session.createConsumer(myDest);

			// ***** Step 7: Start the connection
			conn.start();

			// ***** Step 8: Instantiate a new listener, set message listener
			//   for consumer
			MessageListener aListener = new MyListener();
			asyncCons.setMessageListener(aListener);

			// Do something else while waiting for the message
			while (true)
			{
				System.out.println("*** Doing Other Work ****");
				Thread.sleep(5000);
			}
		}
		catch (InterruptedException i)
		{
			System.out.println("Interrupted :" + i.toString());
			System.exit(1);
		}
		catch (JMSException e)
		{
			System.out.println("Exception in receive message  :" + e.toString());
			System.exit(1);
		}
		finally
		{
			if (conn != null)
			try
			{
				// ****** Step 9: Close Connection
				conn.close();
			}
			catch(JMSException e)
			{
				System.out.println("Exception:" + e.toString());
			}
		}
	}
}

