// TIBCO Enterprise for JMS
// File: SimpleBrowser.java
// TIBCO Education Services
// Copyright 2003 - TIBCO Software Inc.
// ALL RIGHTS RESERVED

import javax.naming.*;
import javax.jms.*;
import java.util.Hashtable;
import java.util.Enumeration;

public class SimpleBrowser
{
	static final String  providerContextFactory =
			                            "com.tibco.tibjms.naming.TibjmsInitialContextFactory";
	static final String  providerURL ="tibjmsnaming://localhost:7222";

	public static void main(String[] args)
	{
		String 				queueName = null;
		Context 				jndiContext = null;
		ConnectionFactory			cFactory = null;
		Connection				conn = null;
		Session				session = null;

		// ***** Step 1: Change Destination to Queue, MessageConsumer to QueueBrowser

		Queue		myDest=null;

		QueueBrowser	myBrowser = null;

		TextMessage	msg = null;

		if (args.length !=1)
		{
			System.out.println("Usage: java SimpleBrowser <queue-name>");
			System.exit(1);
		}

		queueName = new String(args[0]);
		System.out.println("Listening on Queue: "+ queueName);

		try
		{
			Hashtable env = new Hashtable();
			env.put(Context.INITIAL_CONTEXT_FACTORY,providerContextFactory);
			env.put(Context.PROVIDER_URL,providerURL);
			jndiContext = new InitialContext(env);
			cFactory = (ConnectionFactory)jndiContext.lookup("QueueConnectionFactory");
			myDest = (Queue)jndiContext.lookup(queueName);
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}

		try
		{
			conn = cFactory.createConnection();
			session = conn.createSession(false,Session.AUTO_ACKNOWLEDGE);

			// ***** Step 2: Create the browser

			myBrowser = session.createBrowser(myDest);

			conn.start();

			// ***** Step 3 Get Enumeration

			Enumeration enum = myBrowser.getEnumeration();

			int i = 0;
			while (enum.hasMoreElements())
			{
				i = i + 1;
				Message inMsg = (Message)enum.nextElement();
				if  (inMsg != null)
				{
					if (inMsg instanceof TextMessage)
					{
						msg = (TextMessage)inMsg;
						System.out.println("Message no: " + i + " " + msg.getText());
					}
					else
					{
						System.out.println("Exiting Program" + inMsg);
						break;
					}
				}
			}
		}
		catch (JMSException e)
		{
			System.out.println("Exception during browsing: " + e.toString());
			System.exit(1);
		}
		finally
		{
			if (conn != null)
			try
			{
				conn.close();
			}
			catch(JMSException e)
			{
				System.out.println("Exception:" + e.toString());
			}
		}
	}
}
