// TIBCO Enterprise for JMS
// File: SimpleSelector.java
// TIBCO Education Services
// Copyright 2003 - TIBCO Software Inc.
// ALL RIGHTS RESERVED

import javax.naming.*;
import javax.jms.*;
import java.util.Hashtable;
import java.util.Enumeration;

public class SimpleSelector
{
	static final String  providerContextFactory =
			                            "com.tibco.tibjms.naming.TibjmsInitialContextFactory";
	static final String  providerURL ="tibjmsnaming://localhost:7222";

	public static void main(String[] args)
	{
		String 			queueName = null;
		Context 			jndiContext = null;
		ConnectionFactory		cFactory = null;
		Connection			conn = null;
		Session			session = null;
		Queue				myDest=null;
		TextMessage			msg = null;
		QueueBrowser		myBrowser = null;
		String			mySelector = "JMSPriority > 3";

		if (args.length < 1)
		{
			System.out.println("Usage: java SimpleSelector <queue-name> [<selector>]");
			System.exit(1);
		}

		queueName = new String(args[0]);
		if  (args.length > 1)  mySelector= args[1];
		System.out.println("Browsing through Queue: "+ queueName + " WHERE " + mySelector);

		try
		{
			Hashtable env = new Hashtable();
			env.put(Context.INITIAL_CONTEXT_FACTORY,providerContextFactory);
			env.put(Context.PROVIDER_URL,providerURL);
			jndiContext = new InitialContext(env);
			cFactory = (ConnectionFactory)jndiContext.lookup("QueueConnectionFactory");
			myDest = (Queue)jndiContext.lookup(queueName);
		}
		catch (NamingException e)
		{
			System.out.println("Could not create JNDI API context: " + e.toString());
			System.exit(1);
		}

		try
		{
			conn = cFactory.createConnection();
			session = conn.createSession(false,Session.AUTO_ACKNOWLEDGE);

			// ***** Step 1: Create the browser with a selector string

			myBrowser = session.createBrowser(myDest, mySelector);

			conn.start();

			Enumeration enum = myBrowser.getEnumeration();

			int i = 0;
			while (enum.hasMoreElements())
			{
				i = i + 1;
				Message inMsg = (Message)enum.nextElement();

				// ***** Step 2: Display the JMS Message ID standard property

				if  (inMsg != null)
				{
         				System.out.println("JMSMessagID: " + inMsg.getJMSMessageID());
					if (inMsg instanceof TextMessage)
					{
						msg = (TextMessage)inMsg;
						System.out.println("Message " + i + " received: " + msg.getText());
					}
					else
					{
						System.out.println("Exiting Program" + inMsg);
						break;
					}
				}
			}
		}
		catch (JMSException e)
		{
			System.out.println("Exception during browsing: " + e.toString());
			System.exit(1);
		}
		finally
		{
			if (conn != null)
			try
			{
				conn.close();
			}
			catch(JMSException e)
			{
				System.out.println("Exception:" + e.toString());
			}
		}
	}
}
