/* 
 * Copyright(c) 2001 TIBCO Software Inc. 
 * All rights reserved.
 * For more information, please contact:
 * TIBCO Software Inc., Palo Alto, California, USA
 * Written By : Medha Samant
 * History : 
 *  Written Date : Nov 2001 
 */
/*
 * CreditReplyMsgListener.java
 * DESCRIPTION : Receives message on credit reply queue
 *               Parses the message and updates inMemoryHash accordingly
 *
 */


import javax.jms.*;
import javax.naming.*;
import java.util.*;
import com.tibco.tibchoc.*;
   
   
   
class CreditReplyMsgListener implements MessageListener
{
    private String _debug;
    private BusinessProcessCoordinator _jbpc;
        
    public CreditReplyMsgListener(BusinessProcessCoordinator bpmObject)
    {
            _debug = "true";
            _jbpc = bpmObject;
    }
   
    public void onMessage(Message message) 
    {
        try
        {
            System.out.println("JBPC : CreditMsgListener : received reply on creditReplyQueue " );
            if(_debug.equalsIgnoreCase("TRUE"))
                    System.out.println("Reply from Credit : " + message.toString());
            processReply(message);
        }
        catch(Exception e) 
        {
            System.out.println("Exception : " + e.toString());
            System.exit(0);
        }
    }
        
    public void processReply(Message message)
    {
        try
        {
            //parse message 
            if(_debug.equalsIgnoreCase("TRUE"))
                System.out.println("JBPC : Inside processCreditReply 111");
                            
            DomDoc domMsg = new DomDoc(((TextMessage)message).getText());
                
            domMsg.parse();
            String orderid = domMsg.get("OrderID");
            String crchkStatus = domMsg.get("Status");
                
            //set Status and Details
            String retCreditStatus = new String();
            String retCreditDetail = new String();
            InMemoryStructure memStruct;
            synchronized(this)
            {
                Hashtable hash = OrderHash.getHashInstance();
                memStruct = (InMemoryStructure)hash.get(orderid);
                retCreditStatus = domMsg.get("Status");
                System.out.println("JBPC : Inside processCreditReply 3");
                if (!retCreditStatus.equalsIgnoreCase("SUCCESS"))
                    retCreditDetail = domMsg.get("Detail");
                else
                    retCreditDetail = "";
                memStruct.setCreditCheck(retCreditStatus, retCreditDetail);
                System.out.println("JBPC : Inside processCreditReply 4");
                    
                hash.put(orderid, memStruct);
            }
            //Check if reply from inventory check is received
            if(memStruct.getInventoryStatus() != null)
            {
                if(_debug.equalsIgnoreCase("TRUE"))
                    System.out.println("JBPC : Done with order id " + orderid);
                _jbpc.sendReplyToWeb(orderid);
            }
        }
        catch(Exception e)
        {
            System.out.println(e.toString());
            System.exit(0);
        }
    }                 
}
