/* 
 * Copyright(c) 2001 TIBCO Software Inc. 
 * All rights reserved.
 * For more information, please contact:
 * TIBCO Software Inc., Palo Alto, California, USA
 * Written By : Medha Samant
 * History : 
 *  Written Date : Nov 2001 
 */

/*
 * DBConnection.java
 * DESCRIPTION : Maintains Database Connection Pool.
 *               Read all the required parameters from the properties file
 *
 */

import java.sql.*;
import java.util.*;
import com.tibco.tibchoc.*;

public class  DBConnection
{
    private String _propertiesFileName;
    protected static Object        _connectionLock = new Object();
    /* Connection Pool Properties */
    protected static Vector        _inuseConnections;
    protected static Vector        _freeConnections;
    protected static int           _sizeConnectionPool;

    /* Connection Properties */
    protected static String        _userName;
    protected static String        _password;
    protected static String        _url;
    protected static String        _driver;
    protected static boolean       _autoCommit   = true;
    protected static boolean       _initialized  = false;
    
    public DBConnection (String fileName) throws Exception
    {
        _propertiesFileName = fileName;
        AppProperties.loadProperties(_propertiesFileName);
    }

    
    public static synchronized void setup() throws Exception
    {
        if ( _initialized == true ) 
        {
            return;
        }
        _initialized = true;
        
        String s = AppProperties.getProperty("DBConnection.poolsize");
        _sizeConnectionPool = Integer.valueOf(s).intValue();
        _userName = AppProperties.getProperty("DBConnection.user");
        _password = AppProperties.getProperty("DBConnection.password");
        _url      = AppProperties.getProperty("DBConnection.url");
        _driver   = AppProperties.getProperty("DBConnection.driver");
        s = AppProperties.getProperty("DBConnection.autoCommit");            
        if ((s!= null) && s.equalsIgnoreCase("false"))
            _autoCommit = false;
        System.out.println("Connecting to DB <" + _url + ">, user <"
                                + _userName + ">, password <" 
                                + _password + ">, driver <"
                                + _driver + ">, poolsize <"
                                + s + ">...");
        Class.forName (_driver);
        _inuseConnections = new Vector(_sizeConnectionPool);
        _freeConnections = new Vector(_sizeConnectionPool);
                    
        for (int i = 0; i < _sizeConnectionPool; i++) 
        {
            Connection con = newConnection(_url, _userName, _password);
            _freeConnections.addElement(con);
            con.setAutoCommit(_autoCommit);
        }
    }
    
    public static Connection newConnection (String url, String user, String password) throws Exception 
    {
        Connection con = DriverManager.getConnection(_url, _userName, _password);
        return con;
    }
    
    public static void freeConnection (Connection con) throws SQLException 
    {
        synchronized(_connectionLock) 
        {
            _inuseConnections.removeElement(con);
            _freeConnections.addElement(con);
            _connectionLock.notify();
        }
    }
    
    public static synchronized Connection getConnection() throws Exception
    {
        // Search in the Free Connection Pool
        while (true) 
        {
            synchronized(_connectionLock) 
            {
                if (_freeConnections.size() > 0) 
                {
                    Connection con = (Connection) _freeConnections.firstElement();
                    _freeConnections.removeElement(con);
                    _inuseConnections.addElement(con);
                    return con;
                }
                // Wait for a connection to get freed
                try 
                {
                    _connectionLock.wait();
                } 
                catch (InterruptedException ie) 
                {
                }
            }
        }
    }
}
