/* 
 * Lab G Exercise 2: Inventory Update adapter
 * Step 1 to 9.
 */

/*
 * InventoryUpdateAdapter.java
 * DESCRIPTION : Updates inventory after statsfying user order using following steps:
 *               Creates durable subscriber on a topic
 *               Receives message on the topic 
 *               Parses the input xml message
 *               Executes stored procedure to update inventory using JDBC to connect to databse
 *
 */


import com.tibco.tibchoc.*;

// Step 1: Import the entire javax.jms package
import javax.jms.*;

public class InventoryUpdateAdapter implements MessageListener
{
    private String _propertiesFileName;
    private String _serverName;
    private String _debug;
    private String _destinationName;
    private String _user;
    private String _password;
    private String _factoryName;
    private String _subscriberName;
  
    private Connection      _Connection = null;
    private Session         _Session;
    private TopicSubscriber _Subscriber;
    private Destination     _Dest;
    
    private DBConnection _dbConnection;

    public InventoryUpdateAdapter (String fileName) throws Exception
    {
        _propertiesFileName = fileName;
    }

    public void init() throws Exception 
    {
        System.out.println("JMS Inventory Update adapter : Starting up....");
        AppProperties.loadProperties(_propertiesFileName);
        _serverName         = AppProperties.getProperty("TIBCHOC.serverName");
        _debug              = AppProperties.getProperty("TIBCHOC.debug");
        _destinationName    = AppProperties.getProperty("TIBCHOC.receiveDestination");
        _user               = AppProperties.getProperty("TIBCHOC.user");
        _password           = AppProperties.getProperty("TIBCHOC.password");
        _factoryName        = AppProperties.getProperty("TIBCHOC.factory");
        _subscriberName     = AppProperties.getProperty("TIBCHOC.durableSubscriber");
        _dbConnection       = new DBConnection(_propertiesFileName);
        _dbConnection.setup();
        openJMSConnection();
    }
    
    public void openJMSConnection() throws Exception
    {
        System.out.println("JMS Inventory Update Adapter : OpenJMSConnection : [" + _serverName + "] Starting up....");
        System.out.println("JMS Inventory CheckAdapter : Receive destination name : " + _destinationName);
           
        TibjmsUtilities.initJNDI(_serverName);
        
        // Step 2: Use the JNDI to obtain a connection factory
        ConnectionFactory factory = (____________________)__________________.______(_factoryName);
        
        // Step 3: Create a connnection using the connection factory
        _Connection = _________.______________________(______,___________);
        
        // Step 4: Create a session using the connection
        _Session = ____________._____________________(______,______________________________);

        // Step 5: Obtain a specific destination
        _Dest = (_______)___________________.________(_destinationName);
        
        // Step 6: Create a durable subscriber
        _Subscriber = ___________.___________________((_____________) ___________, _subscriberName);

        System.out.println("Inventory Update Adapter : Created Durable Subscriber: " + _subscriberName);        
        _Subscriber.________________(_____);

        // Step 7: Start a connection
        _________________.______();
        synchronized (this) 
        {
            try 
            {
                this.wait();
            } 
            catch (InterruptedException ie) {}
        }
    }

    // Step 8: Receive asynchronous delivered message
    public void ______________(Message msg)
    {
        System.out.println("JMS Inventory Update Adapter : Received Message ");
        
        if(_debug.equalsIgnoreCase("TRUE"))
            System.out.println("MESSAGE : " + msg);

        try
        {
		    //Inventory Update
		    //Parse message to get itemNames and itemQuantities
                    
            DomDoc xmlMsg = new DomDoc(((TextMessage)msg).getText());
            xmlMsg.parse();
            String orderid = xmlMsg.get("OrderID");
            System.out.println("JMS Inventory UpdateAdapter : Received message : " + orderid);
            int NumberOfItems = xmlMsg.getLength("Items");
            String items = "";
            String quantity = "";
            for(int i=0; i< NumberOfItems; i++)
            {
                if (i>0)
                {
                    items += "|";
                    quantity += "|";
                }
                items += xmlMsg.getNthElement("ItemName", i);
                quantity += xmlMsg.getNthElement("Quantity", i);

                if(_debug.equalsIgnoreCase("TRUE"))
                {
                    System.out.println("JMS Inventory UpdateAdapter : Items : " + items);
                    System.out.println("JMS Inventory UpdateAdapter : Quantity : " + quantity);
                }
            }

		    //Execute stored procedure
            java.sql.Connection conn = _dbConnection.getConnection();
                    
            java.sql.CallableStatement cstmt = conn.prepareCall
                ("{call inventory_data_update (?,?,?,?)}");
            cstmt.setString(1,items);
            cstmt.setString(2,quantity);
            cstmt.registerOutParameter(3, java.sql.Types.LONGVARCHAR);
            cstmt.registerOutParameter(4, java.sql.Types.LONGVARCHAR);
            cstmt.execute();
            _dbConnection.freeConnection(conn);

            if(_debug.equalsIgnoreCase("TRUE"))
			    System.out.println("JMS Inventory UppdateAdapter : Inside receiveAndReply : Finished");
        }
        catch(Exception e)
        {
            e.printStackTrace();
        }
    }

    public void closeConnection()
    {
        try
        {
            if (_Connection!=null)
            {
                // Step 9: Close the connection
                _______________.______();
                _Connection = null;
            }
        }
        catch(JMSException e)
        {
            e.printStackTrace();
        }
    }
    
    public static void main(String args[])
    {
        InventoryUpdateAdapter invUpAdp = null;
        try 
        {
             invUpAdp = new InventoryUpdateAdapter(args[0]);
             invUpAdp.init();
        }
        catch (Exception e) 
        {
            e.printStackTrace();
            invUpAdp.closeConnection();
        }
    }
}

