
/* 
 * Lab E: JNDI connection to JMS server
 * Step 1 to 4.
 */

/*
 * This sample uses JNDI to retrieve administered objects.
 *
 * Optionally all parameters hardcoded in this sample can be 
 * read from the jndi.properties file.
 *
 */

import java.util.Hashtable;

// Step 1. Importing the JNDI classes and Interfaces.
import javax.naming.*;
import javax.jms.*;


public class TibjmsUtilities
{
    static Context jndiContext = null;
    
    // Step 1. Define the initial context environment properties
    // a. Initial context factory class name
    static final String  providerContextFactory = "com.tibco.tibjms.naming.TibjmsInitialContextFactory"; 
                            
    // Step 2. Define the initial context environment properties
    // b. Provider URL
    static final String  defaultProviderURL = "tibjmsnaming:\\localhost:7222";
                            
    public static void initJNDI(String providerURL) throws NamingException 
    {
        if (jndiContext != null)
            return;
            
        if (providerURL == null || (providerURL.length() == 0))
            providerURL = defaultProviderURL;
        
        try 
        {
            Hashtable env = new Hashtable();
            env.put(Context.INITIAL_CONTEXT_FACTORY,providerContextFactory);
            env.put(Context.PROVIDER_URL,providerURL);
            	    
            // Step 3. Instantiated an InitialContext object and set its environment properties. 
            jndiContext = new InitialContext(env);
        } 
        catch (NamingException e)
        {
            System.out.println("Failed to create JNDI InitialContext with provider URL set to "+
	                            providerURL+", error = "+e.toString());
            throw e;
        }
    }
        
    public static Object lookup(String objectName) throws NamingException
    {
        if (objectName == null)
            throw new IllegalArgumentException("null object name not legal");
        
        if (objectName.length() == 0)
            throw new IllegalArgumentException("empty object name not legal");
        
        /* 
         * check if not initialized, then initialize
         * with default parameters
         */
        initJNDI(null);
        
        /*
         * do the lookup
         */
	    // Step 4. Looking up a specified administered object.
	    return jndiContext.lookup(objectName);
    }
}


