import com.tibco.tibchoc.*;

import javax.jms.*;


public class ServletTester implements MessageListener
{
    private String _serverName;
    private String _debug;
    private String _user;
    private String _password;
    
    private QueueConnectionFactory _qFactory;
    private QueueConnection _qConnection;
    
    private QueueSession    _qSession;
    
    private Queue           _webReceiveDestination,
                            _webReplyDestination;
                    
    private QueueReceiver   _webReceiver;
    private QueueSender     _webReplier;
    
    public ServletTester () throws Exception
    {
    }

    public void init() throws Exception 
    {
        System.out.println("Business Process Coordinator : init ");
        _serverName    = "tcp://localhost:7222";
        _debug         = "TRUE";
        _user          = "TIBCHOCADMIN";
        _password      = "TIBCHOCADMIN";
        openJMSConnection();
    }
    
    public void initialize()
    {
        //initialization of Connection Factories and creation of connection
        try
        {
            TibjmsUtilities.initJNDI(_serverName);
            _qFactory = (QueueConnectionFactory)TibjmsUtilities.lookup("QueueConnectionFactory");
            _qConnection = _qFactory.createQueueConnection(_user, _password);
            _qSession = _qConnection.createQueueSession(false,Session.AUTO_ACKNOWLEDGE);            
        } 
        catch (Exception e) 
        {
            System.out.println(e.toString());
            closeAll();
            System.exit(0);
        }
    }   
        
    public void openJMSConnection()
    {
        try 
        {
            System.out.println("JBPC : openJMSConnection ");
            initialize();
            
            //To receive messages from servlet and reply back
            _webReceiveDestination = (Queue)TibjmsUtilities.lookup("TIBCO.TIBCHOC.WEB2BPC");
            _webReceiver    = _qSession.createReceiver(_webReceiveDestination);
            _webReceiver.setMessageListener(this);         
            _webReplier     = _qSession.createSender(null);
            System.out.println("JBPC : Receiver created : WEB2BPC : TIBCO.TIBCHOC.WEB2BPC");
            
            _qConnection.start();
            
             synchronized (this) 
             {
                try 
                {
                    this.wait();
                } 
                catch (InterruptedException ie) {}
             }
            
        }
        catch(Exception e)
        { 
            System.out.println(e.toString());
            closeAll();
            System.exit(0);
        }
    }
       
    public void onMessage(Message message) 
    {
        System.out.println("JBPC : Received Message From Servlet");
        if(_debug.equalsIgnoreCase("TRUE"))
            System.out.println("Message :  "+ message.toString());

        try
        {
            //Parse message
            DomDoc msgFromServlet = new DomDoc(((TextMessage)message).getText());
            msgFromServlet.parse();
            Queue retDestination = (Queue)message.getJMSReplyTo();
            String orderid = msgFromServlet.get("OrderID");
            System.out.println("JBPC : Order Id :  "+ orderid);
            
            //create dummy reply
            DomDocOut webReplyDoc = new DomDocOut();
            webReplyDoc.createRoot("Order");
            webReplyDoc.add("OrderID",orderid);
            webReplyDoc.add("Status", "SUCCESS");
            webReplyDoc.add("Detail", " ");
            TextMessage wMessage = _qSession.createTextMessage();
            wMessage.setText(webReplyDoc.toString());
            
            //send reply to servlet
            Queue replyToDestination = (Queue)message.getJMSReplyTo();
            _webReplier.send(replyToDestination, wMessage);
            
            
        } 
        catch(Exception e) 
        {
            System.out.println(e.toString());
            closeAll();
            System.exit(0);
        }
    }
       
    private void closeAll()
    {
        try
        {
            if (_qConnection!=null)
            {
                _qConnection.close();
                _qConnection = null;
            }
        }
        catch(JMSException e)
        {
            System.out.println(e.toString());
        }
    }

    public static void main (String[] args)
    {
        try{
            ServletTester bpc = new ServletTester();
            bpc.init();
        } catch (Exception e){
            System.out.println(e.toString());
            System.exit(0);
        }
    } 
}
 