/* 
 * Copyright(c) 2001 TIBCO Software Inc. 
 * All rights reserved.
 * For more information, please contact:
 * TIBCO Software Inc., Palo Alto, California, USA
 * Written By : Kiet Duong
 * History : 
 *  Written Date : Nov 2001 
 */

/*
 * CreditAdmin.java
 * DESCRIPTION :An adminstrative tool to manage a flat file for a similated Credit System. This will
 *              allow a user to do the following:
 *              list    - to display a list of registered credit cards
 *              add     - to either register a new credit card or update the credit limit of an existing one
 *              delete  - to remove a credit card from the registered list
 *              check   - to check if this credit card is registered
 *              limit   - to find out the current limit balance of a registered credit card
 *
 */

package com.tibco.tibchoc;

import java.io.*;

public class CreditAdmin
{
    public static void main(String[] args)
    {
        try
        {
            CreditSystem cs = new CreditSystem("XYZ_Credit.bin");
            if (args.length==0)
            {
                displayHelp();
            }
            else if (args[0].equalsIgnoreCase("list"))
            {
                cs.getCreditList();
            }
            else if (args[0].equalsIgnoreCase("check") && args.length==3)
            {
                if (cs.checkIfCreditExists(args[1], args[2]))
                    System.out.println("Valid credit card");
                else
                    System.out.println("Invalid credit card");
            }
            else if (args[0].equalsIgnoreCase("limit") && args.length==3)
            {
                double amount = cs.getCreditLimitBalance(args[1], args[2]);
                System.out.println("Credit limit balance: " + amount);
            }
            else if (args[0].equalsIgnoreCase("add") && args.length==4)
            {
                cs.addCreditInfo(args[1], args[2], Double.parseDouble(args[3]));
                cs.getCreditList();
            }
            else if (args[0].equalsIgnoreCase("delete") && args.length==3)
            {
                cs.deleteCreditInfo(args[1], args[2]);
                cs.getCreditList();
            }
            else
                displayHelp();
        }
        catch(IOException ioe)
        {
            ioe.printStackTrace();
        }
        catch(Exception e)
        {
            e.printStackTrace();
        }
    }
    
    private static void displayHelp()
    {
        System.out.println("");
        System.out.println("Usage: CreditAdmin [command]");
        System.out.println("[command]");
        System.out.println("list    - to display a list of registered credit cards");
        System.out.println("          eg. CreditAdmin list");
        System.out.println("add     - to either register a new credit card or update the credit limit of an existing one");
        System.out.println("          eg. CreditAdmin add 1234567812345678 visa 5000.00");
        System.out.println("delete  - to remove a credit card from the registered list");
        System.out.println("          eg. CreditAdmin delete 1234567812345678 visa");
        System.out.println("check   - to check if this credit card is registered");
        System.out.println("          eg. CreditAdmin check 1234567812345678 visa");
        System.out.println("limit   - to find out the current limit balance of a registered credit card");
        System.out.println("          eg. CreditAdmin limit 1234567812345678 visa");
        System.exit(-1);
    }
}