/* 
 * Copyright(c) 2001 TIBCO Software Inc. 
 * All rights reserved.
 * For more information, please contact:
 * TIBCO Software Inc., Palo Alto, California, USA
 * Written By : Kiet Duong
 * History : 
 *  Written Date : Nov 2001 
 */

/*
 * CreditSystem.java
 * DESCRIPTION :An interface to access to a flat file for the Credit System similation. This will
 *              allow a user to do the following:
 *              - to display a list of registered credit cards
 *              - to either register a new credit card or update the credit limit of an existing one
 *              - to remove a credit card from the registered list
 *              - to check if this credit card is registered
 *              - to find out the current limit balance of a registered credit card
 *
 */

package com.tibco.tibchoc;

import java.io.*;
import java.lang.*;
import java.util.*;

public class CreditSystem
{
    Vector m_buffer = null;
    String m_filename = null;

    public CreditSystem(String filename) throws IOException, ClassNotFoundException
    {
        if (filename==null)
        {
	        filename = new String("Customer.bin");
        }
        m_filename = new String(filename);

        // check to see if credit file exist
        File creditFile = new File(m_filename);
        if (!creditFile.exists())
        {
            // Create a new credit file
	        creditFile = new File(m_filename);
	        FileOutputStream ostream = new FileOutputStream(creditFile);
	        ObjectOutputStream p = new ObjectOutputStream(ostream);
	        Vector creditInfo = new Vector(1000,100);
	        p.writeObject(creditInfo);
	        ostream.close();
	        creditFile = null;
        }

        // Load the credit file into memory
        creditFile = new File(m_filename);
        FileInputStream istream = new FileInputStream(creditFile);
        ObjectInputStream p = new ObjectInputStream(istream);
	    m_buffer = (Vector) p.readObject();
        istream.close();
	}

	public void addCreditInfo(String creditNumber, String creditType, double creditBalance) throws Exception, IOException
	{
		CreditRecord cr = null;
		boolean found = false;
		int foundIndex = 0;
		for (int ax=0;ax<m_buffer.size();ax++)
		{
			cr = (CreditRecord) m_buffer.elementAt(ax);
			if (cr.cardNumber.equalsIgnoreCase(creditNumber) && cr.cardType.equalsIgnoreCase(creditType))
			{
				found = true;
				foundIndex = ax;
				break;
			}
		}

		if (found)
		{
			cr.limitBalance = creditBalance;
			m_buffer.setElementAt(cr,foundIndex);
		}
		else
		{
			CreditRecord newCr = new CreditRecord();
			newCr.cardType = creditType;
			newCr.cardNumber = creditNumber;
			newCr.limitBalance = creditBalance;
			m_buffer.add(newCr);
		}				
		finalize();
	}
		
	public boolean deleteCreditInfo(String creditNumber, String creditType) throws Exception, IOException
	{
		boolean found = false;
		int foundIndex = 0;
		CreditRecord cr = null;
		for (int ax=0;ax<m_buffer.size();ax++)
		{
			cr = (CreditRecord) m_buffer.elementAt(ax);
			if (cr.cardNumber.equalsIgnoreCase(creditNumber) && cr.cardType.equalsIgnoreCase(creditType))
			{
				found = true;
				foundIndex = ax;
				break;
			}
		}

		if (found)
		{
			m_buffer.remove(foundIndex);
		}
		finalize();
		return found;
	}

	public void getCreditList() throws Exception
	{
        CreditRecord cr;
        for (int ax=0;ax<m_buffer.size();ax++)
        {
	        cr = (CreditRecord) m_buffer.elementAt(ax);
	        System.out.println("Card ID: "+cr.cardNumber);
	        System.out.println("Card Type: "+cr.cardType);
	        System.out.println("Credit limit balance: "+cr.limitBalance);
	        System.out.println(" ");
        }
		System.out.println("record count: "+m_buffer.size());
	}

	public boolean checkIfCreditExists(String creditCardNumber, String creditCardType) throws Exception
	{
		boolean found = false;
		CreditRecord cr;
		for (int ax=0;ax<m_buffer.size();ax++)
		{
			cr = (CreditRecord) m_buffer.elementAt(ax);
			if (cr!=null && cr.cardNumber.equalsIgnoreCase(creditCardNumber) && cr.cardType.equalsIgnoreCase(creditCardType))
			{
				found = true;
				break;
			}
		}
		return found;
	}
	
	public double getCreditLimitBalance(String creditCardNumber, String creditCardType) throws Exception
	{
	    // Returns -1.00 if credit card does not match. Otherwise return the corresponding credit limit
	    // amount for the specified credit card.
	    
		double amount = -1.00;
		CreditRecord cr;
		for (int ax=0;ax<m_buffer.size();ax++)
		{
			cr = (CreditRecord) m_buffer.elementAt(ax);
			if (cr.cardNumber.equals(creditCardNumber) && cr.cardType.equals(creditCardType))
			{
				amount = cr.limitBalance;
				break;
			}
		}
		return amount;
	}

	public void finalize() throws IOException
	{
		File creditFile = new File(m_filename);
		FileOutputStream ostream = new FileOutputStream(creditFile);
		ObjectOutputStream p = new ObjectOutputStream(ostream);
		p.writeObject(m_buffer);
		ostream.close();
		creditFile = null;
	}	  
}
