/* 
 * Copyright(c) 2001 TIBCO Software Inc. 
 * All rights reserved.
 * For more information, please contact:
 * TIBCO Software Inc., Palo Alto, California, USA
 * Written By : Medha Samant
 * History : 
 *  Written Date : Nov 2001 
 */

/*
 * DomDocOut.java
 * DESCRIPTION :  Wraps DOM code to make life a little easier
 *                Create XML doc 
 *
 */

package com.tibco.tibchoc;

import java.io.StringWriter;
import java.io.FileWriter;
import java.io.File;

import org.w3c.dom.Element;
import org.w3c.dom.Text;
import org.apache.xerces.dom.DocumentImpl;

import org.apache.xml.serialize.OutputFormat;
import org.apache.xml.serialize.Serializer;
import org.apache.xml.serialize.SerializerFactory;
import org.apache.xml.serialize.XMLSerializer;
import org.w3c.dom.NodeList;
import org.w3c.dom.Node;


public class DomDocOut extends DomDoc
{
    private Element _docRoot;
    public static final String NULL_REPLY_XML_OUTPUT =
	        "<?xml version = \"1.0\"?><reply>NOT AVAILABLE</reply>";


    public DomDocOut( String xml )
    {
        super(xml);
    }

    public DomDocOut()
    {
        try
        {
            _domDoc  = new DocumentImpl();
        }
        catch (Exception x)
        {
            System.out.println("error creating DOM Document object " + x);
        }
    }

    public void createRoot( String root )
    {
        try
        {
            _docRoot = _domDoc.createElement(root);
            _domDoc.appendChild( _docRoot );
        }
        catch (Exception x)
        {
            System.out.println("error creating DOM Document root object " + x);
        }
    }


    public Element root()
    {
        return _docRoot;
    }


    public Element add( String name )
    {
        Element e = _domDoc.createElement(name);

        _docRoot.appendChild( e );

        return e;
    }


    public Element add( String name, String value )
    {
        Element e = _domDoc.createElement(name);

        Text text = _domDoc.createTextNode(value);
        e.appendChild( text );
        _docRoot.appendChild( e );

        return e;
    }


    public Element add( Element parent, String name )
    {
        Element e = _domDoc.createElement(name);

        parent.appendChild( e );

        return e;
    }

    public Element add( Element parent, String name, String value )
    {
        Element e = _domDoc.createElement(name);

        Text text = _domDoc.createTextNode(value);
        e.appendChild( text );
        parent.appendChild( e );

        return e;
    }


    public String toString()
    {
        String xmlOut = NULL_REPLY_XML_OUTPUT;
        OutputFormat    format = new OutputFormat( _domDoc );   //Serialize DOM
        StringWriter stringOut = new StringWriter();     //Writer will be a String
        XMLSerializer   serial = new XMLSerializer( stringOut, format );
        try
        {
            serial.serialize( _domDoc.getDocumentElement() );
            xmlOut = stringOut.toString();
           // System.out.println( "\n" + xmlOut +"\n" ); //Spit out DOM as a String
        }
        catch (Exception x)
        {
            System.out.println("Unable to serialise DOM to XML "+x);
        }
        return xmlOut;
    }


    public boolean toFile(String fileName)
    {
        boolean ok = false;
        String xml = toString();

        File file = new File(fileName);

        try
        {
            FileWriter fw = new FileWriter(file);
            fw.write(xml);
            fw.close();
        }
        catch (Exception x)
        {
	        System.out.println("error writing to file '"+fileName+"'" + x);
        }

        return ok;
    }
 
    public void importNode(Node input, boolean bol){
        Node _node = _domDoc.importNode(input, true);
        _docRoot.appendChild(_node );
    }
}
